@@ -13,6 +13,7 @@ SEXP R_zgees(SEXP JOBVS, SEXP SORT, SEXP SELECT, SEXP N,
 		SEXP INFO){
 	int n = INTEGER(N)[0], total_length;
 	SEXP RET, RET_NAMES, T;
+	char CS_JOBVS = CHARPT(JOBVS, 0)[0], CS_SORT = CHARPT(SORT, 0)[0];
 
 	/* Protect R objects. */
 	PROTECT(RET = allocVector(VECSXP, 1));
@@ -28,11 +29,21 @@ SEXP R_zgees(SEXP JOBVS, SEXP SORT, SEXP SELECT, SEXP N,
 	Memcpy(COMPLEX(T), COMPLEX(A), total_length);
 
 	/* Call Fortran. */
-	F77_CALL(zgees)(CHARPT(JOBVS, 0), CHARPT(SORT, 0),
-		fake_select, INTEGER(N), COMPLEX(T), INTEGER(LDA),
-		INTEGER(SDIM), COMPLEX(W), COMPLEX(VS), INTEGER(LDVS),
-		COMPLEX(WORK), INTEGER(LWORK),
-		REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
+	if(CS_JOBVS == 'V' && CS_SORT == 'N'){
+		F77_CALL(zgees)("V", "N",
+			fake_select, INTEGER(N), COMPLEX(T), INTEGER(LDA),
+			INTEGER(SDIM), COMPLEX(W), COMPLEX(VS), INTEGER(LDVS),
+			COMPLEX(WORK), INTEGER(LWORK),
+			REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
+	} else if(CS_JOBVS == 'N' && CS_SORT == 'N'){
+		F77_CALL(zgees)("N", "N",
+			fake_select, INTEGER(N), COMPLEX(T), INTEGER(LDA),
+			INTEGER(SDIM), COMPLEX(W), COMPLEX(VS), INTEGER(LDVS),
+			COMPLEX(WORK), INTEGER(LWORK),
+			REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
+	} else{
+		REprintf("Input (CHARACTER) types are not implemented.\n");
+	}
 
 	/* Return. */
 	UNPROTECT(3);
